Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(71)

Unified Diff: src/IceTargetLoweringX86Base.h

Issue 1279833005: Inline memcpy for small constant sizes. (Closed) Base URL: https://chromium.googlesource.com/native_client/pnacl-subzero.git@master
Patch Set: Created 5 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | src/IceTargetLoweringX86BaseImpl.h » ('j') | tests_lit/llvm2ice_tests/nacl-mem-intrinsics.ll » ('J')
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/IceTargetLoweringX86Base.h
diff --git a/src/IceTargetLoweringX86Base.h b/src/IceTargetLoweringX86Base.h
index 40966a2f6d0920c5266cc9703d97e3344c20f04c..00632d56f65d51a7e11353673219c6992c2651c9 100644
--- a/src/IceTargetLoweringX86Base.h
+++ b/src/IceTargetLoweringX86Base.h
@@ -154,7 +154,9 @@ protected:
Operand *Val);
void lowerCountZeros(bool Cttz, Type Ty, Variable *Dest, Operand *FirstVal,
Operand *SecondVal);
- /// Replace a function call with inline instructions.
+ /// Replace a call to memcpy with inline instructions.
+ void lowerMemcpy(Operand *Dest, Operand *Src, Operand *Count);
+ /// Replace a call to memset with inline instructions.
void lowerMemset(Operand *Dest, Operand *Val, Operand *Count);
/// Lower an indirect jump adding sandboxing when needed.
« no previous file with comments | « no previous file | src/IceTargetLoweringX86BaseImpl.h » ('j') | tests_lit/llvm2ice_tests/nacl-mem-intrinsics.ll » ('J')

Powered by Google App Engine
This is Rietveld 408576698